==> haskell-uri-bytestring-aeson-0.1.0.9-125.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-bytestring-aeson
version:              0.1.0.9
visibility:           public
id:                   uri-bytestring-aeson-0.1.0.9-Br4iNV5VVhhBDRG6y4gbHn
key:                  uri-bytestring-aeson-0.1.0.9-Br4iNV5VVhhBDRG6y4gbHn
license:              BSD-3-Clause
maintainer:           hafnersimon@gmail.com
author:               Simon Hafner
homepage:             https://github.com/reactormonk/uri-bytestring-aeson
synopsis:             Aeson instances for URI Bytestring
category:             URI
abi:                  10bab0f68b8111076711fd506ea6f45e
exposed:              True
exposed-modules:      URI.ByteString.Aeson
import-dirs:          /usr/lib/ghc-9.6.6/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/uri-bytestring-aeson-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring-aeson
hs-libraries:         HSuri-bytestring-aeson-0.1.0.9-Br4iNV5VVhhBDRG6y4gbHn
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    bytestring-0.11.5.3 text-2.0.2
    uri-bytestring-0.3.3.1-LSXEGwh1Eq99RsqnFGBgp8

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring-aeson/html/uri-bytestring-aeson.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-bytestring-aeson-0.1.0.9-126-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-bytestring-aeson
version:              0.1.0.9
visibility:           public
id:                   uri-bytestring-aeson-0.1.0.9-F7Kt9b9MjeW2AlXOgGIaAU
key:                  uri-bytestring-aeson-0.1.0.9-F7Kt9b9MjeW2AlXOgGIaAU
license:              BSD-3-Clause
maintainer:           hafnersimon@gmail.com
author:               Simon Hafner
homepage:             https://github.com/reactormonk/uri-bytestring-aeson
synopsis:             Aeson instances for URI Bytestring
category:             URI
abi:                  35497f6b36e831a5a3433a0c5a116d14
exposed:              True
exposed-modules:      URI.ByteString.Aeson
import-dirs:          /usr/lib/ghc-9.6.6/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/uri-bytestring-aeson-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring-aeson
hs-libraries:         HSuri-bytestring-aeson-0.1.0.9-F7Kt9b9MjeW2AlXOgGIaAU
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    bytestring-0.11.5.3 text-2.0.2
    uri-bytestring-0.3.3.1-ABUb28LEu2c8RUJdcl5zx0

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring-aeson/html/uri-bytestring-aeson.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
